@@ -137,12 +137,6 @@ def setup_services(provider, memory_llm=None):
         memory_service = ChromaMemoryService(
             llm_service=llm_manager.initialize_standalone_service(memory_llm)
         )
-    # use groq if not defined if available
-    # elif os.getenv("GROQ_API_KEY"):
-    #     memory_service = ChromaMemoryService(
-    #         llm_service=llm_manager.initialize_standalone_service("groq")
-    #     )
-    # fallback to default provider if no memory_llm specified
     else:
         memory_service = ChromaMemoryService(
             llm_service=llm_manager.initialize_standalone_service(provider)
@@ -176,12 +170,6 @@ def setup_services(provider, memory_llm=None):
         click.echo(f"⚠️ Image generation service not available: {str(e)}")
         image_gen_service = None
 
-    # try:
-    #     scraping_service = ScrapingService()
-    # except Exception as e:
-    #     click.echo(f"⚠️ Scraping service not available: {str(e)}")
-    #     scraping_service = None
-
     # Clean up old memories (older than 1 month)
     try:
         removed_count = memory_service.cleanup_old_memories(months=1)
@@ -549,6 +537,7 @@ def a2a_server(
         # Get agent manager
         agent_manager = AgentManager.get_instance()
 
+        agent_manager.enforce_transfer = False
         # Create and start server
         from AgentCrew.modules.a2a.server import A2AServer
 
