@@ -59,6 +59,12 @@ class AgentTaskManager(TaskManager):
         self.streaming_tasks: Dict[str, asyncio.Queue] = {}
         self.file_handler = None
 
+        self.agent = self.agent_manager.get_agent(self.agent_name)
+        if self.agent is None or not isinstance(self.agent, LocalAgent):
+            raise ValueError(f"Agent {agent_name} not found or is not a LocalAgent")
+
+        self.memory_service = self.agent.services["memory"]
+
     async def on_send_message(
         self, request: SendMessageRequest | SendStreamingMessageRequest
     ) -> SendMessageResponse:
@@ -71,8 +77,7 @@ class AgentTaskManager(TaskManager):
         Returns:
             JSON-RPC response with task result
         """
-        agent = self.agent_manager.get_agent(self.agent_name)
-        if not agent or not isinstance(agent, LocalAgent):
+        if not self.agent or not isinstance(self.agent, LocalAgent):
             return SendMessageResponse(
                 root=JSONRPCErrorResponse(
                     id=request.id,
@@ -84,14 +89,15 @@ class AgentTaskManager(TaskManager):
 
         # Generate task ID from message
         task_id = (
-            request.params.message.taskId or f"task_{request.params.message.messageId}"
+            request.params.message.task_id
+            or f"task_{request.params.message.message_id}"
         )
 
         if task_id not in self.tasks:
             # Create task with initial state
             task = Task(
                 id=task_id,
-                context_id=request.params.message.contextId or f"ctx_{task_id}",
+                context_id=request.params.message.context_id or f"ctx_{task_id}",
                 status=TaskStatus(
                     state=TaskState.working, timestamp=datetime.now().isoformat()
                 ),
@@ -127,7 +133,7 @@ class AgentTaskManager(TaskManager):
         self.task_history[task_id].append(message)
 
         # Process with agent (non-blocking)
-        asyncio.create_task(self._process_agent_task(agent, task))
+        asyncio.create_task(self._process_agent_task(self.agent, task))
 
         # Return initial task state
         return SendMessageResponse(
@@ -148,7 +154,8 @@ class AgentTaskManager(TaskManager):
         """
         # Generate task ID from message
         task_id = (
-            request.params.message.taskId or f"task_{request.params.message.messageId}"
+            request.params.message.task_id
+            or f"task_{request.params.message.message_id}"
         )
 
         # Create streaming queue
@@ -271,6 +278,23 @@ class AgentTaskManager(TaskManager):
                             )
 
                 if tool_uses and len(tool_uses) > 0:
+                    if task.id in self.streaming_tasks:
+                        queue = self.streaming_tasks[task.id]
+                        artifact = convert_agent_response_to_a2a_artifact(
+                            "",
+                            artifact_id=f"artifact_{task.id}_{len(artifacts)}",
+                            tool_uses=tool_uses,
+                        )
+                        await queue.put(
+                            TaskArtifactUpdateEvent(
+                                task_id=task.id,
+                                context_id=task.context_id,
+                                artifact=artifact,
+                            )
+                        )
+                        # prevent the execute_tool_call take the control of event loop before queue has been process
+                        await asyncio.sleep(0.7)
+
                     # Add thinking content as a separate message if available
                     thinking_data = (
                         (thinking_content, thinking_signature)
@@ -298,21 +322,6 @@ class AgentTaskManager(TaskManager):
 
                     # Process each tool use
                     for tool_use in tool_uses:
-                        if task.id in self.streaming_tasks:
-                            queue = self.streaming_tasks[task.id]
-
-                            artifact = convert_agent_response_to_a2a_artifact(
-                                f"\n```tool_call\ntool_name: {tool_use['name']}\nInput: {tool_use['input']}\n```",
-                                artifact_id=f"artifact_{task.id}_{len(artifacts)}",
-                            )
-                            await queue.put(
-                                TaskArtifactUpdateEvent(
-                                    task_id=task.id,
-                                    context_id=task.context_id,
-                                    artifact=artifact,
-                                )
-                            )
-
                         try:
                             tool_result = await agent.execute_tool_call(
                                 tool_use["name"],
@@ -338,21 +347,7 @@ class AgentTaskManager(TaskManager):
                             if error_message:
                                 self.task_history[task.id].append(error_message)
 
-                    if task.id in self.streaming_tasks:
-                        queue = self.streaming_tasks[task.id]
-
-                        artifact = convert_agent_response_to_a2a_artifact(
-                            "\n",
-                            artifact_id=f"artifact_{task.id}_{len(artifacts)}",
-                        )
-                        await queue.put(
-                            TaskArtifactUpdateEvent(
-                                task_id=task.id,
-                                context_id=task.context_id,
-                                artifact=artifact,
-                            )
-                        )
-                    await _process_task()
+                    return await _process_task()
                 return current_response
 
             current_response = await _process_task()
@@ -365,6 +360,14 @@ class AgentTaskManager(TaskManager):
                 )
                 if assistant_message:
                     self.task_history[task.id].append(assistant_message)
+                user_message = (
+                    self.task_history[task.id][0]
+                    .get("content", [{}])[0]
+                    .get("text", "")
+                )
+                self.memory_service.store_conversation(
+                    user_message, current_response, self.agent_name
+                )
 
             # Create artifact from final response
             artifact = convert_agent_response_to_a2a_artifact(
