@@ -2,7 +2,7 @@ from datetime import datetime
 import os
 import asyncio
 from typing import Dict, Any, List, Optional, Callable
-from AgentCrew.modules.llm.base import BaseLLMService
+from AgentCrew.modules.llm import BaseLLMService
 from AgentCrew.modules.llm.message import MessageTransformer
 from AgentCrew.modules.agents.base import BaseAgent, MessageType
 from AgentCrew.modules import logger
@@ -76,15 +76,18 @@ class LocalAgent(BaseAgent):
         """
 
         if self.services.get("agent_manager"):
-            from AgentCrew.modules.agents.tools.delegate import (
-                register as register_delegate,
-                delegate_tool_prompt,
-            )
-
-            register_delegate(self.services["agent_manager"], self)
             self.tool_prompts.append(
-                delegate_tool_prompt(self.services["agent_manager"])
+                self.services["agent_manager"].get_agents_list_prompt()
             )
+            # from AgentCrew.modules.agents.tools.delegate import (
+            #     register as register_delegate,
+            #     delegate_tool_prompt,
+            # )
+            #
+            # register_delegate(self.services["agent_manager"], self)
+            # self.tool_prompts.append(
+            #     delegate_tool_prompt(self.services["agent_manager"])
+            # )
             if not self.is_remoting_mode:
                 from AgentCrew.modules.agents.tools.transfer import (
                     register as register_transfer,
@@ -99,7 +102,7 @@ class LocalAgent(BaseAgent):
             if self.services and tool_name in self.services:
                 service = self.services[tool_name]
                 if service:
-                    if tool_name == "memory":
+                    if tool_name == "memory" and not self.is_remoting_mode:
                         from AgentCrew.modules.memory.tool import (
                             register as register_memory,
                             adaptive_instruction_prompt,
@@ -254,11 +257,13 @@ class LocalAgent(BaseAgent):
             if mcp_manager.initialized:
                 mcp_manager.initialize_for_agent(self.name)
 
-        system_prompt = self.get_system_prompt()
+        system_prompt = (
+            f"<Agent_Instructions>\n{self.get_system_prompt()}\n</Agent_Instructions>"
+        )
         if self.custom_system_prompt:
-            system_prompt = system_prompt + "\n---\n\n" + self.custom_system_prompt
+            system_prompt = f"{system_prompt}\n\n{self.custom_system_prompt}"
         if self.tool_prompts:
-            system_prompt = system_prompt + "\n---\n\n" + "\n".join(self.tool_prompts)
+            system_prompt = f"{system_prompt}\n\n{'\n\n'.join(self.tool_prompts)}"
 
         self.llm.set_system_prompt(self._parse_system_prompt(system_prompt))
         self.llm.temperature = self.temperature if self.temperature is not None else 0.4
@@ -459,39 +464,60 @@ class LocalAgent(BaseAgent):
             adaptive_behaviors = self.services[
                 "context_persistent"
             ].get_adaptive_behaviors(self.name)
-            if (
-                len(adaptive_behaviors.keys()) > 0
-                and final_messages[-1].get("role", "assistant") == "user"
+            # adaptive behaviors are only added if the last message is from the user
+            if isinstance(final_messages[-1]["content"], str) or (
+                isinstance(final_messages[-1]["content"], list)
+                and final_messages[-1]["content"][0].get("type") != "tool_result"
             ):
-                # adaptive behaviors are only added if the last message is from the user
-                if isinstance(final_messages[-1]["content"], str) or (
-                    isinstance(final_messages[-1]["content"], list)
-                    and final_messages[-1]["content"][0].get("type") != "tool_result"
+                adaptive_messages = {
+                    "role": "user",
+                    "content": [],
+                }
+                if (
+                    self.services.get("agent_manager")
+                    and self.services["agent_manager"].enforce_transfer
                 ):
+                    adaptive_messages["content"].append(
+                        {
+                            "type": "text",
+                            "text": """Before processing my request:
+- Break my request into sub-tasks when applicable.
+- For each sub-task, evaluate other agents capabilities.
+- Transfer sub-task to other agent if they are more suitable. 
+- Keep the evaluating quick and concise using xml format within <agent_evaluation> tags.""",
+                        }
+                    )
+
+                if len(adaptive_behaviors.keys()) > 0:
                     adaptive_text = ""
                     for key, value in adaptive_behaviors.items():
                         adaptive_text += f"- {value} (id:{key})\n"
-
-                    adaptive_messages = {
-                        "role": "user",
-                        "content": [
-                            {
-                                "type": "text",
-                                "text": f"""**ADAPTIVE BEHAVIORS CHECK**: Execute any matching active behaviors "when...do..." patterns immediately—these override standard responses.
-
-**Active Behaviors**: {adaptive_text}
-
-**Execution Rules**:
-• Match conditions → Execute behaviors
-• Unclear match → Ask for clarification  
-• Multiple matches → Apply most specific
-• No stored behaviors → Proceed with standard response
-
-**Note**: Use behaviors as response triggers only, not as memory search terms.""",
-                            }
-                        ],
-                    }
-                    final_messages.insert(-1, adaptive_messages)
+                    adaptive_messages["content"].append(
+                        {
+                            "type": "text",
+                            "text": f"""# MANDATORY: APPLY list of adaptive behaviors before responding. When "when...do..." conditions match, modify your behaviors immediately—they override default logic.
+Ask for clarification if uncertain which behaviors apply.
+## List of adaptive behaviors:
+{adaptive_text}
+END OF ADAPTABLE BEHAVIORS.""",
+                        }
+                    )
+                print(adaptive_messages)
+                last_user_index = -1
+                for i, msg in reversed(list(enumerate(final_messages))):
+                    if msg.get("role", "assistant") == "user":
+                        last_user_index = i
+                        break
+                if (
+                    len(final_messages[last_user_index].get("content", [])) > 0
+                    and final_messages[last_user_index]["content"][0]
+                    .get("text", "")
+                    .find("<transfer_tool>")
+                    == 0
+                ):
+                    adaptive_messages["content"].pop(0)
+                if len(adaptive_messages["content"]) > 0:
+                    final_messages.insert(last_user_index, adaptive_messages)
         try:
             async with await self.llm.stream_assistant_response(
                 final_messages
@@ -508,6 +534,29 @@ class LocalAgent(BaseAgent):
                     ) = self.llm.process_stream_chunk(
                         chunk, assistant_response, _tool_uses
                     )
+                    # if (
+                    #     "<agent_evaluation>" in assistant_response
+                    #     and "</agent_evaluation>" not in assistant_response
+                    # ):
+                    #     continue
+                    # transfer_index_start = assistant_response.find("<agent_evaluation>")
+                    # transfer_index_end = assistant_response.find("</agent_evaluation>")
+                    # if transfer_index_start >= 0 and transfer_index_end >= 0:
+                    #     assistant_response = (
+                    #         assistant_response[:transfer_index_start]
+                    #         + assistant_response[transfer_index_end + 19 :]
+                    #     )
+                    # if chunk_text:
+                    #     chunk_transfer_index_start = chunk_text.find(
+                    #         "<agent_evaluation>"
+                    #     )
+                    #     if chunk_transfer_index_start >= 0:
+                    #         chunk_text = chunk_text[:chunk_transfer_index_start]
+                    #     chunk_transfer_index_end = chunk_text.find(
+                    #         "</agent_evaluation>"
+                    #     )
+                    #     if chunk_transfer_index_end >= 0:
+                    #         chunk_text = chunk_text[chunk_transfer_index_end + 19 :]
                     yield (assistant_response, chunk_text, thinking_chunk)
 
                     if tool_uses:
@@ -525,6 +574,11 @@ class LocalAgent(BaseAgent):
 
         except GeneratorExit as e:
             logger.warning(f"Stream processing interrupted: {e}")
+            return
+        except Exception as e:
+            print(final_messages)
+            logger.error(f"Error during message processing: {e}")
+            raise e
 
     def get_process_result(self):
         return (self.tool_uses, self.input_tokens_usage, self.output_tokens_usage)
