@@ -29,7 +29,7 @@ class GithubCopilotService(CustomLLMService):
                 "Editor-Version": "Neovim/0.9.0",
             },
         )
-        self.model = "gpt-4.1"
+        self.model = "gpt-5-mini"
         self.current_input_tokens = 0
         self.current_output_tokens = 0
         self._is_thinking = False
@@ -120,7 +120,7 @@ class GithubCopilotService(CustomLLMService):
         message = {
             "role": "tool",
             "tool_call_id": tool_use["id"],
-            "name": tool_use["name"],
+            # "name": tool_use["name"],
             "content": tool_result,  # Groq and deepinfra expects string content
         }
         # Add error indication if needed
