@@ -392,9 +392,9 @@ class CustomLLMService(OpenAIService):
                         # Create a new tool call entry
                         tool_uses.append(
                             {
-                                "id": f"toolu_{len(tool_uses)}"
+                                "id": getattr(tool_call_delta, "id")
                                 if hasattr(tool_call_delta, "id")
-                                else None,
+                                else f"toolu_{len(tool_uses)}",
                                 "name": getattr(tool_call_delta.function, "name", "")
                                 if hasattr(tool_call_delta, "function")
                                 else "",
@@ -406,7 +406,7 @@ class CustomLLMService(OpenAIService):
 
                     # Update existing tool call with new data
                     if hasattr(tool_call_delta, "id") and tool_call_delta.id:
-                        tool_uses[tool_call_index]["id"] = f"toolu_{len(tool_uses)}"
+                        tool_uses[tool_call_index]["id"] = tool_call_delta.id
 
                     if hasattr(tool_call_delta, "function"):
                         if (
