@@ -85,7 +85,6 @@ class GoogleAINativeService(BaseLLMService):
         # Provider name and system prompt
         self._provider_name = "google"
         self.system_prompt = ""
-        self.temperature = 0.4
         logger.info("Initialized Google Service")
 
     def set_think(self, budget_tokens) -> bool:
@@ -362,7 +361,7 @@ class GoogleAINativeService(BaseLLMService):
             Any: Result of the tool execution
         """
         if tool_name not in self.tool_handlers:
-            return f"Error: Tool '{tool_name}' not found"
+            raise ValueError(f"Tool '{tool_name}' not found")
 
         try:
             handler = self.tool_handlers[tool_name]
