@@ -22,7 +22,7 @@ class MCPService:
         """Initialize the MCP service."""
         self.sessions: Dict[str, ClientSession] = {}
         self.connected_servers: Dict[str, bool] = {}
-        self.tools_cache: Dict[str, Dict[str, Any]] = {}
+        self.tools_cache: Dict[str, Dict[str, Tool]] = {}
         self.loop = asyncio.new_event_loop()
         self._server_connection_tasks: Dict[str, asyncio.Task] = {}
         self._server_shutdown_events: Dict[str, asyncio.Event] = {}
@@ -385,6 +385,30 @@ class MCPService:
                 "description": tool.description,
                 "input_schema": tool.inputSchema,
             }
+        if provider == "github_copilot":
+            from jsonref import replace_refs
+            import json
+
+            merged_inputSchema_string = json.dumps(
+                replace_refs(
+                    tool.inputSchema,
+                    merge_props=True,
+                    jsonschema=True,
+                ),
+                indent=2,
+            )
+            merged_inputSchema = json.loads(merged_inputSchema_string)
+            if "$defs" in merged_inputSchema:
+                del merged_inputSchema["$defs"]
+            return {
+                "type": "function",
+                "function": {
+                    "name": namespaced_name,
+                    "description": tool.description,
+                    "parameters": merged_inputSchema,
+                },
+            }
+
         else:  # Default format (OpenAI-compatible)
             return {
                 "type": "function",
